#!/usr/bin/env python
# vim: set ts=4 sts=4 sw=4 textwidth=92:

class MessageType (object):
	Fatal = -1
	Normal = 0
	Verbose = 1
	Debug = 2

class RarslaveMessage (object):
	def __init__ (self, msg, type=MessageType.Normal):
		self.msg = msg
		self.type = type

	def __repr__ (self):
		return "%s" % self.msg

	def isFatal (self):
		return self.type == MessageType.Fatal

	def isNormal (self):
		return self.type == MessageType.Normal

	def isVerbose (self):
		return self.type == MessageType.Verbose

	def isDebug (self):
		return self.type == MessageType.Debug

class RarslaveLogger (object):
	# This class will log multiple messages, one for each set that is operated on.
	# It will then be able to print all of them out.

	def __init__ (self):
		self.__messages = []

	def addMessage (self, msg, type=MessageType.Normal):
		self.__messages.append (RarslaveMessage (msg, type))

	def hasFatalMessages (self):
		for m in self.__messages:
			if m.isFatal ():
				return True

		return False

	def hasNormalMessages (self):
		for m in self.__messages:
			if m.isNormal ():
				return True

		return False

	def hasVerboseMessages (self):
		for m in self.__messages:
			if m.isVerbose ():
				return True

		return False

	def hasDebugMessages (self):
		for m in self.__messages:
			if m.isDebug ():
				return True

		return False

	def printAllMessages (self, level=MessageType.Normal):
		# Print all messages with level upto and including $level.
		for m in self.__messages:
			if m.type <= level:
				print m

	def printLoglevel (self, level=MessageType.Normal):
		# Print all message with exactly the loglevel given
		for m in self.__messages:
			if m.type == level:
				print m

def main ():
	pass

if __name__ == '__main__':
	main ()

